-------------------------------------------------
-- Help text for techs
-------------------------------------------------

function GetHelpTextForTech( iTechID )
	local pTechInfo = GameInfo.Technologies[iTechID];
	
	local pActiveTeam = Teams[Game.GetActiveTeam()];
	local pActivePlayer = Players[Game.GetActivePlayer()];
	local pTeamTechs = pActiveTeam:GetTeamTechs();
	local iTechCost = pActivePlayer:GetResearchCost(iTechID);
	
	local strHelpText = "";

	-- Name
	strHelpText = strHelpText .. Locale.ToUpper(Locale.ConvertTextKey( pTechInfo.Description ));

	-- Do we have this tech?
	if (pTeamTechs:HasTech(iTechID)) then
		strHelpText = strHelpText .. " [COLOR_POSITIVE_TEXT](" .. Locale.ConvertTextKey("TXT_KEY_RESEARCHED") .. ")[ENDCOLOR]";
	end

	-- Cost/Progress
	strHelpText = strHelpText .. "[NEWLINE]-------------------------[NEWLINE]";
	
	local iProgress = pActivePlayer:GetResearchProgress(iTechID);
	local bShowProgress = true;
	
	-- Don't show progres if we have 0 or we're done with the tech
	if (iProgress == 0 or pTeamTechs:HasTech(iTechID)) then
		bShowProgress = false;
	end
	
	if (bShowProgress) then
		strHelpText = strHelpText .. Locale.ConvertTextKey("TXT_KEY_TECH_HELP_COST_WITH_PROGRESS", iProgress, iTechCost);
	else
		strHelpText = strHelpText .. Locale.ConvertTextKey("TXT_KEY_TECH_HELP_COST", iTechCost);
	end
	
	-- REALISM MOD START
	-- Add PreTechs information
	local strNeeds = "";
	local bFirstNeeds = true;
	for row in GameInfo.Technology_PrereqTechs() do
		local pPrereqTech = GameInfo.Technologies[row.PrereqTech];
		local pNeedsTech = GameInfo.Technologies[row.TechType];
		
		if (pPrereqTech and pNeedsTech) then
			if (pTechInfo.ID == pNeedsTech.ID) then
				
				-- If this isn't the first leads-to tech, then add a comma to separate
				if (bFirstNeeds) then
					bFirstNeeds = false;
				else
					strNeeds = strNeeds .. ", ";
				end
				
				if (pActiveTeam:GetTeamTechs():HasTech(pPrereqTech.ID)) then
					strNeeds = strNeeds .. "[COLOR:255:222:22:255]" .. Locale.ConvertTextKey( pPrereqTech.Description ) .. "[/COLOR]";
				else 
					if (pActivePlayer:CanResearch( pPrereqTech.ID )) then
						strNeeds = strNeeds .. "[COLOR_POSITIVE_TEXT]" .. Locale.ConvertTextKey( pPrereqTech.Description ) .. "[ENDCOLOR]";
					else
						strNeeds = strNeeds .. Locale.ConvertTextKey( pPrereqTech.Description );
					end
				end
			end
		end
	end
	for row in GameInfo.Technology_ORPrereqTechs() do
		local pPrereqTech = GameInfo.Technologies[row.PrereqTech];
		local pNeedsTech = GameInfo.Technologies[row.TechType];
		
		if (pPrereqTech and pNeedsTech) then
			if (pTechInfo.ID == pNeedsTech.ID) then
				
				-- If this isn't the first leads-to tech, then add a comma to separate
				if (bFirstNeeds) then
					bFirstNeeds = false;
				else
					strNeeds = strNeeds .. ", ";
				end
				
				if (pActiveTeam:GetTeamTechs():HasTech(pPrereqTech.ID)) then
					strNeeds = strNeeds .. "[COLOR:255:222:22:255]" .. Locale.ConvertTextKey( pPrereqTech.Description ) .. "[/COLOR]";
				else 
					if (pActivePlayer:CanResearch( pPrereqTech.ID )) then
						strNeeds = strNeeds .. "[COLOR_POSITIVE_TEXT]" .. Locale.ConvertTextKey( pPrereqTech.Description ) .. "[ENDCOLOR]";			
					else
						strNeeds = strNeeds .. Locale.ConvertTextKey( pPrereqTech.Description );
					end
				end
			end
		end
	end
	
	if (strNeeds ~= "") then
		strHelpText = strHelpText .. "[NEWLINE]";
		strHelpText = strHelpText .. Locale.ConvertTextKey("TXT_KEY_TECH_HELP_NEEDS", strNeeds);
	end
	-- REALISM MOD END
	
	-- Leads to...
	local strLeadsTo = "";
	local bFirstLeadsTo = true;
	for row in GameInfo.Technology_PrereqTechs() do
		local pPrereqTech = GameInfo.Technologies[row.PrereqTech];
		local pLeadsToTech = GameInfo.Technologies[row.TechType];
		
		if (pPrereqTech and pLeadsToTech) then
			if (pTechInfo.ID == pPrereqTech.ID) then
				
				-- If this isn't the first leads-to tech, then add a comma to separate
				if (bFirstLeadsTo) then
					bFirstLeadsTo = false;
				else
					strLeadsTo = strLeadsTo .. ", ";
				end
				
				strLeadsTo = strLeadsTo .. "[COLOR_POSITIVE_TEXT]" .. Locale.ConvertTextKey( pLeadsToTech.Description ) .. "[ENDCOLOR]";
			end
		end
	end
	
	if (strLeadsTo ~= "") then
		strHelpText = strHelpText .. "[NEWLINE]";
		strHelpText = strHelpText .. Locale.ConvertTextKey("TXT_KEY_TECH_HELP_LEADS_TO", strLeadsTo);
	end

	-- Pre-written help text
	strHelpText = strHelpText .. "[NEWLINE]-------------------------[NEWLINE]";
	strHelpText = strHelpText .. Locale.ConvertTextKey( pTechInfo.Help );
	
	
	-- REALISM MOD START
	-- Additional information
	if (not pTeamTechs:HasTech(iTechID)) then
		local iNumHasTech = 0;
		local iNumHasEmbassy = 0;
		for iPlayer = 0, GameDefines.MAX_CIV_PLAYERS - 1 do	
			local pPlayer = Players[iPlayer];
			local pTeam = Teams[pPlayer:GetTeam()];
			if (pPlayer:IsAlive() and not pPlayer:IsMinorCiv() and iPlayer ~= Game.GetActivePlayer() and pActiveTeam:IsHasMet(pPlayer:GetTeam())) then
				if (pActiveTeam:HasEmbassyAtTeam(pPlayer:GetTeam())) then
					iNumHasEmbassy = iNumHasEmbassy + 1;
					if pTeam:GetTeamTechs():HasTech(iTechID) then
						iNumHasTech = iNumHasTech + 1;
					end
				end
			end
		end
	
		if iNumHasTech > 0 and iNumHasEmbassy > 0 then
			strHelpText = strHelpText .. "[NEWLINE]-------------------------[NEWLINE]";
			strHelpText = strHelpText .. Locale.ConvertTextKey("TXT_KEY_TECH_SCIENCE_FROM_ENVIRONMENT_HELP", iNumHasTech, iNumHasEmbassy, pActivePlayer:GetScienceFromEnvironmentTimes100(pTechInfo.ID) / 100);
		end
	end
	
	-- Tech Trade
	if (pActivePlayer:IsHasAnotherTechSource(iTechID)) then
		local pOtherPlayer = Players[ pActivePlayer:GetTechSource(iTechID) ]
		local otherName;
		if (pOtherPlayer:IsHuman()) then
			otherName = pOtherPlayer:GetNickName();
		else
			otherName = pOtherPlayer:GetName();
		end
		local iScienceAdd = (pActivePlayer:GetScience() + pOtherPlayer:GetScience()) / 2 / 2;
		strHelpText = strHelpText .. "[NEWLINE]-------------------------[NEWLINE]";
		strHelpText = strHelpText .. Locale.ConvertTextKey("TXT_KEY_TECH_TRADING", otherName, iScienceAdd);
	end
	-- REALISM MOD END
	
	return strHelpText;
end